@@ -1,7 +1,7 @@
 #!/usr/bin/env python
+from __future__ import print_function
 import stretch_body.robot_params
 stretch_body.robot_params.RobotParams.set_logging_level("DEBUG")
-from __future__ import print_function
 from stretch_body.hello_utils import *
 import sys
 import stretch_body.wrist_yaw as wrist_yaw
@@ -13,7 +13,7 @@ args=parser.parse_args()
 
 poses = {'zero':0, 'left':deg_to_rad(90), 'right': deg_to_rad(-45)}
 w=wrist_yaw.WristYaw()
-if not w.startup():
+if not w.startup(threaded=False):
     exit()
 
 v_des=w.params['motion']['default']['vel']
